summaryrefslogtreecommitdiffstats
path: root/libksieve/parser
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:50:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:50:21 -0600
commit3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12 (patch)
tree89de88213bd261e4ccaade899ab2d6ec34b3a5a7 /libksieve/parser
parent1dad5f662a09dfc5cc041caffe0f674044a4dcec (diff)
downloadtdepim-3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.tar.gz
tdepim-3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'libksieve/parser')
-rw-r--r--libksieve/parser/lexer.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libksieve/parser/lexer.cpp b/libksieve/parser/lexer.cpp
index a38c6102..3bc75c96 100644
--- a/libksieve/parser/lexer.cpp
+++ b/libksieve/parser/lexer.cpp
@@ -40,7 +40,7 @@
#include <tqstring.h>
#include <tqstringlist.h>
-#include <tqtextcodec.h>
+#include <textcodec.h>
#include <memory> // std::auto_ptr
@@ -476,9 +476,9 @@ namespace KSieve {
const int identifierLength = mState.cursor - identifierStart;
// Can use the fast tqfromLatin1 here, since identifiers are always
// in the us-ascii subset:
- result += TQString::tqfromLatin1( identifierStart, identifierLength );
+ result += TQString::fromLatin1( identifierStart, identifierLength );
if ( atEnd() || isDelim( *mState.cursor ) )
return true;
@@ -476,9 +476,9 @@ namespace KSieve {
const int identifierLength = mState.cursor - identifierStart;
- // Can use the fast tqfromLatin1 here, since identifiers are always
+ // Can use the fast fromLatin1 here, since identifiers are always
// in the us-ascii subset: